@@ -5,7 +5,7 @@ import inspect
 import sys
 import time
 import memory_profiler
-import pyrsistent_vector_test
+import vector_test
 
 try:
     from pvectorc import pvector
@@ -22,12 +22,13 @@ def run_function(fn):
         fn(pvector)
 
 def detect_memory_leak(samples):
-    # Skip the first half to get rid of the build up period
-    samples = samples[len(samples)/2:]
-    return not samples.count(samples[0]) == len(samples)
+    # Skip the first half to get rid of the build up period and the last since it seems
+    # a little less precise
+    samples = samples[int(len(samples)/2):len(samples)-1]
+    return not samples.count(samples[0]) > len(samples) - 2
 
 def profile_tests():
-    test_functions = [fn for fn in inspect.getmembers(pyrsistent_vector_test, inspect.isfunction)
+    test_functions = [fn for fn in inspect.getmembers(vector_test, inspect.isfunction)
                       if fn[0].startswith('test_')]
 
     for name, fn in test_functions:
@@ -35,7 +36,7 @@ def profile_tests():
         fn_args = inspect.getargspec(fn)[0]
         if 'pvector' in fn_args:
             print('Executing %s' % name)
-            result = memory_profiler.memory_usage((run_function, (fn,), {}))
+            result = memory_profiler.memory_usage((run_function, (fn,), {}), interval=.1)
             assert not detect_memory_leak(result), (name, result)
 
 if __name__ == "__main__":
